@@ -1,6 +1,12 @@
 """
-    Parse INI files.
+    Inirama is a python module that parses INI files.
 
+    .. include:: ../README.rst
+       :start-line: 5
+       :end-line: 12
+
+    :copyright: 2013 by Kirill Klenov.
+    :license: BSD, see LICENSE for more details.
 """
 from __future__ import unicode_literals, print_function
 
@@ -10,7 +16,7 @@ import logging
 from collections import OrderedDict, MutableMapping
 
 
-__version__ = '0.2.8'
+__version__ = '0.3.0'
 __project__ = 'Inirama'
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
@@ -101,7 +107,7 @@ class Scanner(object):
 
 class INIScanner(Scanner):
     patterns = [
-        ('SECTION', re.compile(r'\[\w+\]')),
+        ('SECTION', re.compile(r'\[[^]]+\]')),
         ('IGNORE', re.compile(r'[ \r\t\n]+')),
         ('COMMENT', re.compile(r'[;#].*')),
         ('KEY', re.compile(r'[\w_]+\s*[:=].*'))]
@@ -179,9 +185,33 @@ class InterpolationSection(Section):
 
 
 class Namespace(object):
+    """ Default class for parsing INI.
 
+        :param **default_items: Default items for default section.
+
+        Usage
+        -----
+
+        ::
+
+            from inirama import Namespace
+
+            ns = Namespace()
+            ns.read('config.ini')
+
+            print ns['section']['key']
+
+            ns['other']['new'] = 'value'
+            ns.write('new_config.ini')
+
+    """
+    #: Name of default section (:attr:`~inirama.Namespace.default`)
     default_section = 'DEFAULT'
+
+    #: Dont raise any exception on file reading erorrs
     silent_read = True
+
+    #: Class for generating sections
     section_type = Section
 
     def __init__(self, **default_items):
@@ -197,6 +227,11 @@ class Namespace(object):
 
     def read(self, *files, **params):
         """ Read and parse INI files.
+
+            :param *files: Files for reading
+            :param **params: Params for parsing
+
+            Set `update=False` for prevent values redefinition.
         """
         for f in files:
             try:
@@ -210,7 +245,7 @@ class Namespace(object):
 
     def write(self, f):
         """
-            Write self as INI file.
+            Write namespace as INI file.
 
             :param f: File object or path to file.
         """
@@ -229,7 +264,10 @@ class Namespace(object):
         f.close()
 
     def parse(self, source, update=True, **params):
-        """ Parse INI source.
+        """ Parse INI source as string.
+
+            :param source: Source of INI
+            :param update: Replace alredy defined items
         """
         scanner = INIScanner(source)
         scanner.scan()
@@ -254,11 +292,30 @@ class Namespace(object):
             self.sections[name] = self.section_type(self)
         return self.sections[name]
 
+    def __contains__(self, name):
+        return name in self.sections
+
     def __repr__(self):
         return "<Namespace: {0}>".format(self.sections)
 
 
 class InterpolationNamespace(Namespace):
+    """ That implements the interpolation feature.
+
+    ::
+
+        from inirama import InterpolationNamespace
+
+        ns = InterpolationNamespace()
+        ns.parse('''
+            [main]
+            test = value
+            foo = bar {test}
+            more_deep = wow {foo}
+        ''')
+        print ns['main']['more_deep']  # wow bar value
+
+    """
 
     section_type = InterpolationSection
 
